<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: adviewnocookies.plugin.php 2507 2005-04-12 13:10:56Z radek $
*/

/**
 * @package    Plugins
 * @subpackage InvocationTags
 * @author     Radek Maciaszek <radek@m3.net>
 *
 */

require_once MAX_PATH . '/plugins/invocationTags/InvocationTags.php';
require_once MAX_PATH . '/lib/max/Plugins/PluginTranslation.php';

/**
 *
 * Invocation tag plugin.
 *
 */
class Plugins_InvocationTags_clickonly_clickonly extends Plugins_InvocationTags 
{
    
    /**
     * Return name of plugin
     *
     * @return string
     */
    function getName()
    {
        return Max_PluginTranslation::translate('Remote Invocation - click only', $this->module, $this->package);
    }
    
    /**
     * Return preference code
     *
     * @return string
     */
    function getPreferenceCode()
    {
        return 'allow_invocation_clickonly';
    }
    
    /**
     * Check if plugin is allowed
     *
     * @return boolean  True - allowed, false - not allowed
     */
    function isAllowed($extra)
    {
        $isAllowed = parent::isAllowed($extra);
        if((is_array($extra) && $extra['delivery'] == phpAds_ZoneText) || $this->maxInvocation->zone_invocation) {
            return false;
        } else {
            return $isAllowed;
        }
    }
    
    /**
     * Return list of options
     *
     * @return array    Group of options
     */
    function getOptionsList()
    {
        if (!$this->maxInvocation->zone_invocation) {
            $options = array (
                'spacer'          => MAX_PLUGINS_INVOCATION_TAGS_CUSTOM,
                'bannerid'        => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
                'target'          => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
                'source'          => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
                'setRequirements' => MAX_PLUGINS_INVOCATION_TAGS_CUSTOM,
            );
        } else {
            $options = array (
                'spacer'          => MAX_PLUGINS_INVOCATION_TAGS_CUSTOM,
                'target'          => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
                'source'          => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
                'setRequirements' => MAX_PLUGINS_INVOCATION_TAGS_CUSTOM,
            );
        }
        
        return $options;
    }    

    /**
     * Return invocation code for this plugin (codetype)
     *
     * @return string
     */
    function generateInvocationCode()
    {
        parent::prepareCommonInvocationData();
        
        $conf = $GLOBALS['_MAX']['CONF'];
        $mi = &$this->maxInvocation;
        
        $buffer  = '<!-- Max Media Manager - Track Clicks Only' . "\n";
        $buffer .= '  --' . "\n";
        $buffer .= '  -- Generated with Max ' . MAX_VERSION_READABLE . "\n";
        $buffer .= '  --' . "\n";
        if ((isset($mi->cachebuster)) && ($mi->cachebuster != '0')) {
            $buffer .= '  -- Replace both instances of INSERT_RANDOM_NUMBER_HERE with' . "\n";
            $buffer .= '  -- a generated random number (or timestamp).' . "\n";
            $buffer .= '  --' . "\n";
        }
        $buffer .= '  -- Replace INSERT_BANNER_SRC with' . "\n";
        $buffer .= '  -- the correct URL of the banner.' . "\n";
        $buffer .= '  --' . "\n";
        $buffer .= '  -- This tag has been generated for use on a non-SSL page. If this tag' . "\n";
        $buffer .= '  -- is to be placed on an SSL page, change the' . "\n";
        $buffer .= '  --   \'http://'.$conf['webpath']['delivery'].'/...\'' . "\n";
        $buffer .= '  -- to' . "\n";
        $buffer .= '  --   \'https://'.$conf['webpath']['deliverySSL'].'/...\'' . "\n";
        $buffer .= '  --' . "\n";
        if (!empty($mi->uniqueid)) {
            $mi->parameters[] = "n=".$mi->uniqueid;    
        }
        $buffer .= "<a href='".constructDeliveryURL($conf['file']['click']);
        $buffer .= "?bannerid=" . $mi->bannerid;
        if ((isset($mi->zoneid)) && ($mi->zoneid != '')) {
            $buffer .= "&zoneid=".$mi->zoneid;
        }
        if ((isset($mi->cachebuster)) && ($mi->cachebuster != '0')) {
            $buffer .= "&cb=INSERT_RANDOM_NUMBER_HERE";
        }
        $buffer .= "'";
        if (isset($mi->target) && $mi->target != '') {
            $buffer .= " target='".$mi->target."'";
        } else {
            $buffer .= " target='_blank'";
        }
        $buffer .= ">\n";
        $buffer .= "<img src='INSERT_BANNER_SRC";
        if (sizeof($mi->parameters) > 0) {
            $buffer .= "?".implode ("&", $mi->parameters);
        }
        $buffer .= "' border='0' alt='' /></a>\n";
        
        return $buffer;
    }

    
    /**
     * Generate the HTML option
     *
     * @return string    A string containing html for option
     */
    function spacer()
    {
        $option = "<tr bgcolor='#F6F6F6'><td height='10' colspan='3'>&nbsp;</td></tr>";
        return $option;
    }
    
    /**
     * Generate the HTML option
     *
     * @return string    A string containing html for option
     */
    function setRequirements()
    {
        $option = '';
        
        $option .= "<script language='JavaScript'>\n";
        $option .= "<!--\n";
        $option .= "\tphpAds_formSetRequirements('bannerid', '".addslashes($GLOBALS['strInvocationBannerID'])."', true)\n";
        $option .= "-->\n";
        $option .= "</script>\n";
        
        return $option;
    }
}

?>
